summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t3.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials/t3.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t3.cs14
1 files changed, 7 insertions, 7 deletions
diff --git a/qtsharp/src/examples/tutorials/t3.cs b/qtsharp/src/examples/tutorials/t3.cs
index a1c76ce4..26fece72 100644
--- a/qtsharp/src/examples/tutorials/t3.cs
+++ b/qtsharp/src/examples/tutorials/t3.cs
@@ -10,17 +10,17 @@ public class Example {
public static int Main (String[] args)
{
- QApplication a = new QApplication (args);
+ TQApplication a = new TQApplication (args);
- QVBox box = new QVBox ();
+ TQVBox box = new TQVBox ();
box.Resize (200, 120);
- QPushButton quit = new QPushButton ("Quit", box);
- quit.SetFont (new QFont ("Times", 18, QFont.Weight.Bold));
- // In C++, QFont::Bold is sufficient
+ TQPushButton quit = new TQPushButton ("Quit", box);
+ quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
+ // In C++, TQFont::Bold is sufficient
- QObject.Connect ( quit, QtSupport.SIGNAL ("clicked()"), a, QtSupport.SLOT ("Quit()") );
- // SIGNAL and SLOT are static functions of QtSupport
+ TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ // TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (box);
box.Show ();